@@ -62,7 +62,7 @@ class Teacher(abstract.LessonbasedTeacher):
         if self.get_bool('config/picky_on_new_question') \
            and (not self.q_status in (const.QSTATUS_NO, const.QSTATUS_SOLVED,
                                       const.QSTATUS_GIVE_UP)):
-           return self.ERR_PICKY
+            return self.ERR_PICKY
         self.m_P.select_random_question()
         self.m_correct = [self.m_P.get_cname() == -1,
                           self.m_P.get_inversion() == -1,
@@ -84,8 +84,8 @@ class Teacher(abstract.LessonbasedTeacher):
         if t == self.m_P.get_cname():
             self.m_correct[0] = 1
             if self.m_correct == [1, 1, 1]:
-               self.q_status = const.QSTATUS_SOLVED
-               return self.ALL_CORRECT
+                self.q_status = const.QSTATUS_SOLVED
+                return self.ALL_CORRECT
             return self.CORRECT
         else:
             return 0
@@ -179,7 +179,6 @@ class Gui(abstract.LessonbasedGui):
                      xoptions=gtk.FILL, yoptions=0)
 
         self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer(utils.play_tone)
-        self.g_music_displayer.set_size_request(150, -1)
         hbox.pack_start(self.g_music_displayer)
 
         self.g_new = gu.bButton(self.action_area, _("_New chord"),
