@@ -15,6 +15,15 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+__exercise_data__ = {
+    'exercise_name': 'harmonic-interval',
+    'menu_path': '%s/%s' % (_("_Intervals"), _("_Harmonic interval")),
+    'icon': 'graphics/harmonicinterval24.png',
+    'toolbar': 2,
+}
+import exercise_setup
+exercise_setup.register_exercise(__exercise_data__)
+
 import gtk, gnome
 import gu, widgets, inputwidgets
 import soundcard, mpd
@@ -22,12 +31,13 @@ import abstract, const, utils
 import statistics, statisticsviewer
 
 class Teacher(abstract.Teacher):
+    exercise_data = __exercise_data__
     OK = 0
     ERR_PICKY = 1
     ERR_NO_INTERVALLS = 2
     ERR_NOTERANGE = 3
-    def __init__(self, exname, app):
-        abstract.Teacher.__init__(self, exname, app)
+    def __init__(self, exname, app, config):
+        abstract.Teacher.__init__(self, exname, app, config)
         self.m_statistics = statistics.HarmonicIntervalStatistics(self)
         self.m_tonika = None
         self.m_interval = None
@@ -44,7 +54,7 @@ class Teacher(abstract.Teacher):
 
         if self.get_bool('config/picky_on_new_question') \
                  and self.q_status in [const.QSTATUS_NEW, const.QSTATUS_WRONG]:
-             return Teacher.ERR_PICKY
+            return Teacher.ERR_PICKY
 
         if self.get_list('intervals') == []:
             self.q_status = const.QSTATUS_NO
@@ -280,7 +290,7 @@ class Gui(abstract.IntervalGui):
             if self.get_int('inputwidget') == 0:
                 self.g_input.grab_focus_first_sensitive_button()
         elif g == Teacher.ERR_PICKY:
-                self.g_flashbar.flash(_("You have to solve this question first."))
+            self.g_flashbar.flash(_("You have to solve this question first."))
         elif g == Teacher.ERR_NO_INTERVALLS:
             self.g_repeat.set_sensitive(False)
             self.g_repeat_melodic.set_sensitive(False)
