@@ -67,7 +67,7 @@ class Teacher(abstract.LessonbasedTeacher):
 
         if self.get_bool('config/picky_on_new_question') \
                  and self.q_status in [const.QSTATUS_NEW, const.QSTATUS_WRONG]:
-             return Teacher.ERR_PICKY
+            return Teacher.ERR_PICKY
 
         self.q_status = const.QSTATUS_NO
 
@@ -98,7 +98,7 @@ class Gui(abstract.LessonbasedGui):
         # practise_box #
         ################
         self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer(utils.play_tone)
-        self.practise_box.pack_start(self.g_music_displayer)
+        self.practise_box.pack_start(self.g_music_displayer, False)
         self.g_bb = widgets.QuestionNameButtonTable(self.m_t.m_exname)
         self.practise_box.pack_start(self.g_bb, False)
 
@@ -216,7 +216,7 @@ class Gui(abstract.LessonbasedGui):
                     cname = self.m_t.m_P.get_unique_cnames()[idx]
                     for question in self.m_t.m_P.m_questions:
                         if question.get_cname() == cname:
-                           question['active'] = 1
+                            question['active'] = 1
         else:
             self.g_new.set_sensitive(False)
     def give_up(self, _o=None):
