@@ -15,14 +15,24 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+__exercise_data__ = {
+    'exercise_name': 'identify-bpm',
+    'menu_path': '%s/%s' % (_("_Rhythm"), _("Bpm")),
+    'icon': 'graphics/identify-bpm24.png',
+    'toolbar': 12,
+}
+import exercise_setup
+exercise_setup.register_exercise(__exercise_data__)
+
 import gnome, gtk
 import soundcard
 import abstract, const, statistics, statisticsviewer, gu, random
 
 
 class Teacher(abstract.Teacher):
-    def __init__(self, exname, app):
-        abstract.Teacher.__init__(self, exname, app)
+    exercise_data = __exercise_data__
+    def __init__(self, exname, app, config):
+        abstract.Teacher.__init__(self, exname, app, config)
         # 60, 84, 100, 120
         self.m_ped = [60, 120, 40, 168, 208, 80, 96, 139, 48, 69, 108, 192, 152,
                       88, 63, 100, 116, 176, 200, 52, 76, 126, 160,
@@ -48,7 +58,7 @@ class Teacher(abstract.Teacher):
         self.set_string('active_bpms', str(v))
     def get_possible_bpms(self):
         v = []
-        for x in self.m_practise_these.keys():
+        for x in self.m_practise_these:
             if self.m_practise_these[x]:
                 v.append(x)
         return v#UGH
@@ -94,6 +104,7 @@ class Teacher(abstract.Teacher):
             self.m_app.play_sad_sound()
     def end_practise(self):
         self.stop_question()
+        self.q_status = const.QSTATUS_NO
     def give_up(self):
         self.stop_question()
         print "FIXME not saving statistics"
@@ -184,6 +195,7 @@ class Gui(abstract.Gui):
             self.g_flashbar.flash(_("Wrong"))
         self.g_statview.update()
     def on_start_practise(self):
+        self.g_flashbar.flash(_("Click 'New tempo' to begin."))
         self.g_new.grab_focus()
     def on_end_practise(self):
         self.m_t.end_practise()
