@@ -24,7 +24,7 @@ class HelpWindow(gtk.Window):
     def __init__(self, parent):
         gtk.Window.__init__(self)
         self.set_title("GNU Solfege lesson file editor help")
-        self.set_size_request(400, 400)
+        self.set_default_size(400, 400)
         self.g_parent = parent
         self.vbox = gtk.VBox()
         self.vbox.set_spacing(8)
@@ -535,21 +535,21 @@ class UIManagerMainWin(MainWin):
         self.toplevel_vbox.pack_start(self.ui.get_widget('/Toolbar'), False)
 
 def main(datadir):
-        global gtk_api
-        mpd.engravers.fetadir = os.path.join(datadir, "feta")
-        if gtk.pygtk_version < (2, 2, 96):
-            gtk_api = "2.0"
-        else:
-            gtk_api = "2.4"
-        if len(sys.argv) > 1 and sys.argv[1] == '--old':
-            gtk_api = "2.0"
-            del sys.argv[1]
+    global gtk_api
+    mpd.engravers.fetadir = os.path.join(datadir, "feta")
+    if gtk.pygtk_version < (2, 2, 96):
+        gtk_api = "2.0"
+    else:
+        gtk_api = "2.4"
+    if len(sys.argv) > 1 and sys.argv[1] == '--old':
+        gtk_api = "2.0"
+        del sys.argv[1]
 
-        if gtk_api == "2.0":
-            w = ItemFactoryMainWin(datadir)
-        else:
-            w = UIManagerMainWin(datadir)
-        if len(sys.argv) == 2:
-            w.load_file(sys.argv[1])
-        w.show()
-        gtk.main()
+    if gtk_api == "2.0":
+        w = ItemFactoryMainWin(datadir)
+    else:
+        w = UIManagerMainWin(datadir)
+    if len(sys.argv) == 2:
+        w.load_file(sys.argv[1])
+    w.show()
+    gtk.main()
