@@ -35,8 +35,8 @@ i18n.setup()
 import configureoutput
 
 def do_some_cmdline_options(argv):
-        if '-h' in argv or '--help' in argv:
-            print """
+    if '-h' in argv or '--help' in argv:
+        print """
 GNU Solfege %s
 Type "man solfege" for more details.
 Options:
@@ -47,20 +47,20 @@ Options:
   -h, --help             Display this message
   --gtk-help             Display the usual gtk/gnome commandline options.
     """ % configureoutput.VERSION_STRING
-            sys.exit()
+        sys.exit()
 
-        if '-v' in argv or '--version' in argv:
-            print """GNU Solfege %s
+    if '-v' in argv or '--version' in argv:
+        print """GNU Solfege %s
 This is free software. It is covered by the GNU General Public License,
 and you are welcome to change it and/or distribute copies of it under
 certain conditions. Invoke as `solfege --warranty` for more information.
 
 Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen <tca@gnu.org>
-            """ % configureoutput.VERSION_STRING
-            sys.exit()
+        """ % configureoutput.VERSION_STRING
+        sys.exit()
 
-        if '-w' in argv or '--warranty' in argv:
-            print """GNU Solfege %s
+    if '-w' in argv or '--warranty' in argv:
+        print """GNU Solfege %s
 Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen <tca@gnu.org>
 
     This program is free software; you can redistribute it and/or
@@ -77,7 +77,7 @@ GNU General Public License along with this program; if not, write to
 the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139,
 USA.
         """ % configureoutput.VERSION_STRING
-            sys.exit()
+        sys.exit()
 
 
 do_some_cmdline_options(sys.argv)
@@ -159,9 +159,9 @@ if splash_win:
 
 import gnome, gnome.ui
 # FIXME we set this because it is not yet added to PyGNOME2
-gnome.ui.PAD=8
-gnome.ui.PAD_SMALL=4
-gnome.ui.PAD_BIG=12
+gnome.ui.PAD = 8
+gnome.ui.PAD_SMALL = 4
+gnome.ui.PAD_BIG = 12
 
 if splash_win:
     splash_win.show_progress("importing application modules")
@@ -211,7 +211,7 @@ class DocViewer(gtk.VBox):
         self.m_htmlwidget = HtmlWidget(activate_cb, self.on_anchor_track)
         self.m_htmlwidget.show_all()
         self.pack_start(self.m_htmlwidget)
-        self.set_size_request(300, 300)
+        self.set_size_request(500, 300)
         #self.read_docfile = self.m_htmlwidget.read_docfile
         self.get_vadjustment = self.m_htmlwidget.get_vadjustment
         self.on_key_press_event = self.m_htmlwidget.on_key_press_event
@@ -262,6 +262,7 @@ class MusicViewerWindow(gtk.Dialog):
 class MainWin(gnome.ui.App, cfg.ConfigUtils):
     def __init__(self, argv):
         gnome.ui.App.__init__(self, 'solfege19', 'GNU Solfege')
+        self.set_default_size(400, 400)
         self.set_icon(gtk.gdk.pixbuf_new_from_file(
                 os.path.join("graphics", "solfege.png")))
         cfg.ConfigUtils.__dict__['__init__'](self, 'mainwin')
@@ -371,7 +372,7 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
             self.box_dict['docviewer'] = DocViewer(self.m_app.handle_href)
             self.main_box.pack_start(self.box_dict['docviewer'])
         if self.m_viewer and (self.m_viewer != 'docviewer'):
-                self.box_dict[self.m_viewer].hide()
+            self.box_dict[self.m_viewer].hide()
         self.m_viewer = 'docviewer'
         self.box_dict['docviewer'].show()
     def display_docfile(self, fn, anchor):
@@ -538,15 +539,6 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
           navitem.set_active(self.get_bool('gui/navbar_visible')))
         menu.add(navitem)
 
-        menu.add(gtk.SeparatorMenuItem())
-
-        item = gtk.CheckMenuItem(_("_User resizeable main window"))
-        item.connect('toggled', self.on_view_menu_user_resizeable_toggled)
-        item.set_active(self.get_bool('gui/mainwin_user_resizeable'))
-        self.add_watch('gui/mainwin_user_resizeable', lambda key:
-          item.set_active(self.get_bool('gui/mainwin_user_resizeable')))
-        menu.add(item)
-
         if configureoutput.WITH_GTKHTML:
             menu.add(gtk.SeparatorMenuItem())
             menu.add(gu.create_stock_menu_item('gtk-zoom-in', _("Help viewer zoom in"),
@@ -561,9 +553,6 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         return menu
     def on_zoom_in(self, *v):
         self.box_dict['docviewer'].m_htmlwidget.g_view.zoom_in()
-    def on_view_menu_user_resizeable_toggled(self, widget):
-        self.set_bool('gui/mainwin_user_resizeable', widget.get_active())
-        self.set_resizable(widget.get_active())
     def on_view_menu_toolbar_visible_toggled(self, widget):
         """
         This function is called when the user selects the View/Toolbar menu
